@@ -4,13 +4,11 @@ import gtk
 import gobject
 import random
 
-VERSION = "0.3.7"
+VERSION = "0.3.8"
 IS_MAEMO = commands.getoutput("uname -m")[0:3] == "arm" # if cpu type is ARM, we are on maemo
 
 # general settings
 db_file = os.path.expanduser("~/.musicdb")
-music_dirs = ("~/music/", "/media/mmc2", "/media/mmc1")
-blacklist_dirs = ("/media/mmc2/map",)
 known_exts = ("mp3", "ogg")
 
 # device specific settings
