@@ -108,19 +108,19 @@ class Controller:
         self._order_menu["artist"].connect("activate", lambda caller: self._set_list_order("artist"))
         self._order_menu["date"].connect("activate", lambda caller: self._set_list_order("date"))
         self._order_menu["playcount"].connect("activate", lambda caller: self._set_list_order("playcount"))
-
+        
         # banner
         self._banner = hildon.hildon_banner_show_animation(self._window, "qgn_indi_pball_a", _("Updating database"))
         self._library.connect("update-complete", self._destroy_banner)
 
-        # start updating thread
-        self._library.update()
+        # start updating library
+        self._library.update(self._config["music-folder"])
     
     def _handle_rpc(self, interface, method, arguments, user_data):
         action = dict();
         action["toggle"] = self._window._controls.on_toggle
-        action["prev"] = self._window._controls.on_prev
-        action["next"] = self._window._controls.on_next
+        action["prev"] = self._player.previous
+        action["next"] = self._player.next
         
         action[method]()
     
@@ -140,6 +140,10 @@ class Controller:
         # order by was added in v0.3.5, therefore check for it seperately
         if not self._config.has_key("order-by"):
             self._config["order-by"] = "artist"
+        
+        # music-folder was added in v0.3.8
+        if not self._config.has_key("music-folder"):
+            self._config["music-folder"] = "/media/mmc2"
 
     def _set_list_order(self, order):
         self._config["order-by"] = order
@@ -176,7 +180,7 @@ class Controller:
             self._player.next()
             return True # event handled
         elif key == "Left":
-            self._window._controls.on_prev()
+            self._player.previous()
             return True # event handled
         if key == "F7":
             self._on_vol_up()
