@@ -2,12 +2,16 @@ import sqlite3
 import gst
 import gobject
 import os
+import sys
+
+
+
 import mutagen
 import mutagen.easyid3
 
 from gobject import GObject
 from threading import Thread
-from youamp import Song, music_dirs, known_exts, db_file, blacklist_dirs
+from youamp import Song, known_exts, db_file
 from mutagen.id3 import ID3NoHeaderError
 
 order = dict()
@@ -98,23 +102,19 @@ class Library(GObject, Thread):
         self._conn.commit()
 
     # start update thread
-    def update(self):
+    def update(self, folder):
+        self._music_dir = folder
         self.start()
 
     def _get_files(self):
         filelist = []
-        for d in music_dirs:
-            path = os.path.expanduser(d)
 
-            for root, dirs, files in os.walk(path):
-                if root.startswith(blacklist_dirs):
-                    continue
-
-                for f in files:
-                    if f.lower().endswith(known_exts):
-                        uri = "file://"+os.path.join(root, f)
-                        uri = uri.replace("%", "%25") #escape the uri escape char
-                        filelist.append(uri)
+        for root, dirs, files in os.walk(self._music_dir):
+            for f in files:
+                if f.lower().endswith(known_exts):
+                    uri = "file://"+os.path.join(root, f)
+                    uri = uri.replace("%", "%25") #escape the uri escape char
+                    filelist.append(uri)
 
         return filelist
  
@@ -148,13 +148,13 @@ class Library(GObject, Thread):
                 try:
                     f = mutagen.easyid3.EasyID3(path)
                 except ID3NoHeaderError:
-                    sys.stderr.write("Bad ID3 Header, skipping: %s" % path)
+                    sys.stderr.write("Bad ID3 Header, skipping: %s\n" % path)
                     continue
             else:
                 f = mutagen.File(path)
                 
             if f is None:
-                sys.stderr.write("Not a media file, skipping: %s" % path)
+                sys.stderr.write("Not a media file, skipping: %s\n" % path)
                 continue
             
             for k, v in f.items():
@@ -162,7 +162,7 @@ class Library(GObject, Thread):
                 try:
                     v = str(", ".join(v))   # flatten value
                 except TypeError:
-                    sys.stderr.write("wrong type for %s in %s" % (k, path))
+                    sys.stderr.write("wrong type for %s in %s\n" % (k, path))
                     continue
                 
                 if k == "tracknumber":                        
@@ -181,10 +181,12 @@ class Library(GObject, Thread):
                     fname = uri.rindex("/")
                     fnend = uri.rindex(".")
                     song["title"] = uri[fname+1:fnend]
-
-            # store metadata in database (uri, title, artist, album, genre, tracknumber)
-            cursor.execute("INSERT INTO songs VALUES (?, ?, ?, ?, ?, ?, 0, datetime('now'))", \
-                (uri, song["title"], song["artist"], song["album"], song["genre"], song["tracknumber"]))
+            
+            mtime = os.path.getmtime(uri[7:].replace("%25", "%")) # strip file:// and unescape
+            
+            # store metadata in database (uri, title, artist, album, genre, tracknumber, date)
+            cursor.execute("INSERT INTO songs VALUES (?, ?, ?, ?, ?, ?, 0, datetime(?, 'unixepoch'))", \
+                (uri, song["title"], song["artist"], song["album"], song["genre"], song["tracknumber"], mtime))
 
             print "Added: %s" % uri
                 
