@@ -27,7 +27,7 @@ class Controls(gtk.HBox):
         prev = gtk.Button()
         prev.set_image(gtk.image_new_from_file(img_path % "media-skip-backward.png"))
         prev.set_size_request(60, -1)
-        prev.connect("clicked", self.on_prev)
+        prev.connect("clicked", lambda caller: self._player.previous())
         prev.unset_flags(gtk.CAN_FOCUS)
         self.pack_start(prev, expand=False)
         
@@ -35,7 +35,7 @@ class Controls(gtk.HBox):
         next.set_image(gtk.image_new_from_file(img_path % "media-skip-forward.png"))
         next.set_size_request(60, -1)
         next.unset_flags(gtk.CAN_FOCUS)
-        next.connect("clicked", self.on_next)
+        next.connect("clicked", lambda caller: self._player.next())
         self.pack_start(next, expand=False)
         
         self.pos = hildon.Seekbar()
@@ -60,9 +60,8 @@ class Controls(gtk.HBox):
         self._config.notify_add("volume", self._on_conf_volume_changed)
         self._config.notify_add("search-str", self._on_song_changed)
         self._player.connect("song-changed", self._on_song_changed)
+        self._player.connect("seek-changed", lambda caller, new_seek: self.pos.set_value(new_seek))
         
-        gobject.timeout_add(1000, self._update_pos)
-    
     def _on_song_changed(self, *args):
         self._update_toggle_img()
         
@@ -74,15 +73,6 @@ class Controls(gtk.HBox):
             self.toggle_button.set_image(gtk.image_new_from_pixbuf(self._pause_img.get_pixbuf()))
         else:
             self.toggle_button.set_image(gtk.image_new_from_pixbuf(self._play_img.get_pixbuf()))
-
-    def on_next(self, caller=None):
-        self._player.next()
-    
-    def on_prev(self, caller=None):
-        if self._player.get_time() > 3:
-            self._player.seek_to(0.0)        
-        else:     
-            self._player.previous()
         
     def on_toggle(self, caller=None):
         self._player.toggle()
@@ -110,7 +100,6 @@ class Controls(gtk.HBox):
         self._config["volume"] = val
         
     def _update_pos(self):
-        if self._player.playing:
-            self.pos.set_value(self._player.get_seek())
+        self.pos.set_value(self._player.get_seek())
         
         return True
