@@ -96,8 +96,9 @@ class SearchView(gtk.VBox):
             self._album.hide()
         
         self._restore_playlist()
-            
-        self._config.notify_add("pos", self._on_pos_changed)
+        
+        self._player.connect("song-changed", self._on_pos_changed)
+        #self._config.notify_add("pos", self._on_pos_changed)
         
         # browser callbacks
         self._config.notify_add("search-artist", self._on_search_artist)
@@ -125,13 +126,13 @@ class SearchView(gtk.VBox):
         self._playlist.set_cursor(self._config["pos"])
 
 
-    def _browse_complete(self):
-        playlist = self._library.get_tracks(self._config)
-        self._set_playlist(playlist)
-        
+    def _browse_complete(self):        
         self._search_entry.set_text("")
         self._config["is-browser"] = True
         
+        playlist = self._library.get_tracks(self._config)
+        self._set_playlist(playlist)
+        
         self._show_playlist()
  
     def _on_search_click(self, caller):
